==> aliyun-python-sdk-alb-1.0.2.tar.gz: aliyun-python-sdk-alb-1.0.2/aliyunsdkalb/request/v20200616/ListSecurityPolicyRelationsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkalb.endpoint import endpoint_data

class ListSecurityPolicyRelationsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Alb', '2020-06-16', 'ListSecurityPolicyRelations','alb')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_SecurityPolicyIds(self): # Array
		return self.get_query_params().get('SecurityPolicyIds')

	def set_SecurityPolicyIds(self, SecurityPolicyIds):  # Array
		for index1, value1 in enumerate(SecurityPolicyIds):
			self.add_query_param('SecurityPolicyIds.' + str(index1 + 1) + '.SecurityPolicyIds', value1)

==> aliyun-python-sdk-alb-1.0.16.tar.gz: aliyun-python-sdk-alb-1.0.16/aliyunsdkalb/request/v20200616/ListSecurityPolicyRelationsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkalb.endpoint import endpoint_data

class ListSecurityPolicyRelationsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Alb', '2020-06-16', 'ListSecurityPolicyRelations','alb')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_SecurityPolicyIds(self): # Array
		return self.get_query_params().get('SecurityPolicyIds')

	def set_SecurityPolicyIds(self, SecurityPolicyIds):  # Array
		for index1, value1 in enumerate(SecurityPolicyIds):
			self.add_query_param('SecurityPolicyIds.' + str(index1 + 1), value1)
